You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2015/04/06 07:34:17 UTC

svn commit: r1671483 - /directory/studio/trunk/plugins/openldap.config.editor/src/main/java/org/apache/directory/studio/openldap/config/model/OlcMdbConfig.java

Author: elecharny
Date: Mon Apr  6 05:34:17 2015
New Revision: 1671483

URL: http://svn.apache.org/r1671483
Log:
Add the olcDbEnvFlags and olcDbMaxEntrySize attribute which have been added since 2.4.33

Modified:
    directory/studio/trunk/plugins/openldap.config.editor/src/main/java/org/apache/directory/studio/openldap/config/model/OlcMdbConfig.java

Modified: directory/studio/trunk/plugins/openldap.config.editor/src/main/java/org/apache/directory/studio/openldap/config/model/OlcMdbConfig.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/openldap.config.editor/src/main/java/org/apache/directory/studio/openldap/config/model/OlcMdbConfig.java?rev=1671483&r1=1671482&r2=1671483&view=diff
==============================================================================
--- directory/studio/trunk/plugins/openldap.config.editor/src/main/java/org/apache/directory/studio/openldap/config/model/OlcMdbConfig.java (original)
+++ directory/studio/trunk/plugins/openldap.config.editor/src/main/java/org/apache/directory/studio/openldap/config/model/OlcMdbConfig.java Mon Apr  6 05:34:17 2015
@@ -47,28 +47,16 @@ public class OlcMdbConfig extends OlcDat
     private String olcDbDirectory;
 
     /**
-     * Field for the 'olcDbMaxSize' attribute.
-     */
-    @ConfigurationElement(attributeType = "olcDbMaxSize")
-    private Long olcDbMaxSize;
-
-    /**
      * Field for the 'olcDbCheckpoint' attribute.
      */
     @ConfigurationElement(attributeType = "olcDbCheckpoint")
     private String olcDbCheckpoint;
 
     /**
      * Field for the 'olcDbNoSync' attribute.
      */
-    @ConfigurationElement(attributeType = "olcDbNoSync")
-    private Boolean olcDbNoSync;
-
-    /**
-     * Field for the 'olcDbMode' attribute.
-     */
-    @ConfigurationElement(attributeType = "olcDbMode")
-    private String olcDbMode;
+    @ConfigurationElement(attributeType = "olcDbEnvFlags")
+    private List<String> olcDbEnvFlags = new ArrayList<String>();
 
     /**
      * Field for the 'olcDbIndex' attribute.
@@ -77,12 +65,36 @@ public class OlcMdbConfig extends OlcDat
     private List<String> olcDbIndex = new ArrayList<String>();
 
     /**
+     * Field for the 'olcDbMaxEntrySize' attribute.
+     */
+    @ConfigurationElement(attributeType = "olcDbMaxEntrySize")
+    private Integer olcDbMaxEntrySize;
+
+    /**
      * Field for the 'olcDbMaxReaders' attribute.
      */
     @ConfigurationElement(attributeType = "olcDbMaxReaders")
     private Integer olcDbMaxReaders;
 
     /**
+     * Field for the 'olcDbMaxSize' attribute.
+     */
+    @ConfigurationElement(attributeType = "olcDbMaxSize")
+    private Long olcDbMaxSize;
+
+    /**
+     * Field for the 'olcDbMode' attribute.
+     */
+    @ConfigurationElement(attributeType = "olcDbMode")
+    private String olcDbMode;
+
+    /**
+     * Field for the 'olcDbNoSync' attribute.
+     */
+    @ConfigurationElement(attributeType = "olcDbNoSync")
+    private Boolean olcDbNoSync;
+
+    /**
      * Field for the 'olcDbSearchStack' attribute.
      */
     @ConfigurationElement(attributeType = "olcDbSearchStack")
@@ -101,12 +113,30 @@ public class OlcMdbConfig extends OlcDat
     }
 
 
+    /**
+     * @param strings
+     */
+    public void addOlcDbEnvFlags( String... strings )
+    {
+        for ( String string : strings )
+        {
+            olcDbEnvFlags.add( string );
+        }
+    }
+
+
     public void clearOlcDbIndex()
     {
         olcDbIndex.clear();
     }
 
 
+    public void clearOlcDbEnvFlags()
+    {
+        olcDbEnvFlags.clear();
+    }
+
+
     /**
      * {@inheritDoc}
      */
@@ -144,6 +174,24 @@ public class OlcMdbConfig extends OlcDat
 
 
     /**
+     * @return the olcDbEnvFlags
+     */
+    public List<String> getOlcDbEnvFlags()
+    {
+        return olcDbEnvFlags;
+    }
+
+
+    /**
+     * @return the olcDbMaxEntrySize
+     */
+    public Integer getOlcDbMaxEntrySize()
+    {
+        return olcDbMaxEntrySize;
+    }
+
+
+    /**
      * @return the olcDbMaxReaders
      */
     public Integer getOlcDbMaxReaders()
@@ -215,6 +263,24 @@ public class OlcMdbConfig extends OlcDat
     }
 
 
+    /**
+     * @param olcDbEnvFlags the olcDbEnvFlags to set
+     */
+    public void setOlcDbEnvFlagsx( List<String> olcDbEnvFlags )
+    {
+        this.olcDbEnvFlags = olcDbEnvFlags;
+    }
+
+
+    /**
+     * @param olcDbMaxEntrySize the olcDbMaxEntrySize to set
+     */
+    public void setOlcDbMaxEntrySize( Integer olcDbMaxEntrySize )
+    {
+        this.olcDbMaxEntrySize = olcDbMaxEntrySize;
+    }
+
+
     /**
      * @param olcDbMaxReaders the olcDbMaxReaders to set
      */
@@ -47,28 +47,16 @@ public class OlcMdbConfig extends OlcDat
 
     /**
-     * Field for the 'olcDbNoSync' attribute.
+     * Field for the 'olcDbEnvFlags' attribute.
      */